@@ -1161,6 +1161,9 @@ class VariableClBuilderBranchRep(ReadonlyVariable):
             return dv.Get('cl_update_rep_name')
         return []
 
+    def humanReadable(self):
+        return [x.capitalize() for x in self.Get()]
+
 
 class VariableClBuilderBranchName(Variable):
     """
@@ -1619,7 +1622,7 @@ class VariableClBuilderEixRepositories(ReadonlyVariable):
 
     def get(self):
         return ", ".join(
-            x for x in chain(
+            x.capitalize() for x in chain(
                 reversed(self.Get('update.cl_update_rep_name')),
                 self.Get('builder.cl_builder_other_rep_name')))
 
